==> zio-aws-serverlessapplicationrepository_2.13-5.17.113.1-sources.jar: zio/aws/serverlessapplicationrepository/model/DeleteApplicationRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteApplicationRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest = {
    import DeleteApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest
      .wrap(buildAwsValue())
}
object DeleteApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest =
      zio.aws.serverlessapplicationrepository.model
        .DeleteApplicationRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
  ) extends zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.applicationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
  ): zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_2.13-5.19.7.6-sources.jar: zio/aws/serverlessapplicationrepository/model/DeleteApplicationRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteApplicationRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest = {
    import DeleteApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest
      .wrap(buildAwsValue())
}
object DeleteApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest =
      zio.aws.serverlessapplicationrepository.model
        .DeleteApplicationRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
  ) extends zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.DeleteApplicationRequest
  ): zio.aws.serverlessapplicationrepository.model.DeleteApplicationRequest.ReadOnly =
    new Wrapper(impl)
}
